# Copyright 2021 (c) Anna Schumaker.
import lib
import tagdb
from gi.repository import GObject
from . import bass
from . import scale
from . import selector


class Player(bass.BassPlayer):
    def __init__(self):
        bass.BassPlayer.__init__(self)
        self.Autopause = scale.AutoPauseScale()
        self.Selector = selector.TagdbSelector()
        self.track = None

        self.change_track(tagdb.Tracks[lib.settings.get_int("audio.trackid")])
        if self.track:
            self.track.add_to_playlist("Previous")

    def change_track(self, track, reset=False):
        if self.track and self.play_percent > (2 / 3):
            self.track.played()
        if reset:
            self.uri = None
        self.emit("track-changed", self.track, track)

    def do_about_to_finish(self):
        if self.Autopause.get_value() != 0:
            self.Autopause.decrement()
            self.change_track(self.Selector.next())

    def do_eos(self):
        self.Autopause.decrement()
        self.change_track(self.Selector.next())
        self.playing = self.Autopause.keep_playing

    def play(self): self.playing = True
    def pause(self): self.playing = False
    def playpause(self): self.playing = not self.playing

    def play_track(self, track):
        self.change_track(track, reset=True)
        self.play()

    def next(self): self.play_track(self.Selector.next())
    def previous(self): self.play_track(self.Selector.previous())

    @GObject.Signal(arg_types=(tagdb.track.Track, tagdb.track.Track))
    def track_changed(self, prev, new):
        self.track = new
        if self.track:
            lib.settings.set("audio.trackid", new.trackid)
            self.uri = new.filepath().absolute().as_uri()
